hepstats package
================

.. automodule:: hepstats
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   hepstats.hypotests
   hepstats.modeling
   hepstats.splot
   hepstats.utils

Submodules
----------

.. toctree::
   :maxdepth: 4

   hepstats.version
